@@ -153,7 +153,8 @@ static Image *ReadDPSImage(const ImageInfo *image_info,ExceptionInfo *exception)
   assert(image_info != (const ImageInfo *) NULL);
   assert(image_info->signature == MagickSignature);
   if (image_info->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),image_info->filename);
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
+      image_info->filename);
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickSignature);
   display=XOpenDisplay(image_info->server_name);
@@ -334,21 +335,21 @@ static Image *ReadDPSImage(const ImageInfo *image_info,ExceptionInfo *exception)
       */
       red_mask=visual_info->red_mask;
       red_shift=0;
-      while ((red_mask & 0x01) == 0)
+      while ((red_mask != 0) && ((red_mask & 0x01) == 0))
       {
         red_mask>>=1;
         red_shift++;
       }
       green_mask=visual_info->green_mask;
       green_shift=0;
-      while ((green_mask & 0x01) == 0)
+      while ((green_mask != 0) && ((green_mask & 0x01) == 0))
       {
         green_mask>>=1;
         green_shift++;
       }
       blue_mask=visual_info->blue_mask;
       blue_shift=0;
-      while ((blue_mask & 0x01) == 0)
+      while ((blue_mask != 0) && ((blue_mask & 0x01) == 0))
       {
         blue_mask>>=1;
         blue_shift++;
