@@ -122,7 +122,8 @@ static Image *ReadMONOImage(const ImageInfo *image_info,
   assert(image_info != (const ImageInfo *) NULL);
   assert(image_info->signature == MagickSignature);
   if (image_info->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),image_info->filename);
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
+      image_info->filename);
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickSignature);
   image=AllocateImage(image_info);
@@ -308,7 +309,7 @@ static MagickBooleanType WriteMONOImage(const ImageInfo *image_info,
   assert(image != (Image *) NULL);
   assert(image->signature == MagickSignature);
   if (image->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),image->filename);
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   status=OpenBlob(image_info,image,WriteBinaryBlobMode,&image->exception);
   if (status == MagickFalse)
     return(status);
@@ -318,7 +319,7 @@ static MagickBooleanType WriteMONOImage(const ImageInfo *image_info,
   */
   (void) SetImageType(image,BilevelType);
   polarity=(IndexPacket)
-    (PixelIntensityToQuantum(&image->colormap[0]) < (MaxRGB/2));
+    (PixelIntensityToQuantum(&image->colormap[0]) < (QuantumRange/2));
   if (image->colors == 2)
     polarity=(IndexPacket) (PixelIntensityToQuantum(&image->colormap[0]) <
       PixelIntensityToQuantum(&image->colormap[1]));
