@@ -191,7 +191,8 @@ static Image *ReadPCLImage(const ImageInfo *image_info,ExceptionInfo *exception)
   assert(image_info != (const ImageInfo *) NULL);
   assert(image_info->signature == MagickSignature);
   if (image_info->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),image_info->filename);
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
+      image_info->filename);
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickSignature);
   /*
@@ -486,7 +487,7 @@ static MagickBooleanType WritePCLImage(const ImageInfo *image_info,Image *image)
   assert(image != (Image *) NULL);
   assert(image->signature == MagickSignature);
   if (image->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),image->filename);
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   status=OpenBlob(image_info,image,WriteBinaryBlobMode,&image->exception);
   if (status == MagickFalse)
     return(status);
@@ -517,7 +518,7 @@ static MagickBooleanType WritePCLImage(const ImageInfo *image_info,Image *image)
       /*
         Write PCL monochrome image.
       */
-      polarity=PixelIntensityToQuantum(&image->colormap[0]) < (MaxRGB/2);
+      polarity=PixelIntensityToQuantum(&image->colormap[0]) < (QuantumRange/2);
       if (image->colors == 2)
         polarity=PixelIntensityToQuantum(&image->colormap[0]) <
           PixelIntensityToQuantum(&image->colormap[1]);
