@@ -160,7 +160,8 @@ static Image *ReadSCTImage(const ImageInfo *image_info,ExceptionInfo *exception)
   assert(image_info != (const ImageInfo *) NULL);
   assert(image_info->signature == MagickSignature);
   if (image_info->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),image_info->filename);
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
+      image_info->filename);
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickSignature);
   image=AllocateImage(image_info);
@@ -227,7 +228,7 @@ static Image *ReadSCTImage(const ImageInfo *image_info,ExceptionInfo *exception)
       break;
     for (x=0; x < (long) image->columns; x++)
     {
-      q->red=(Quantum) (MaxRGB-ScaleCharToQuantum(ReadBlobByte(image)));
+      q->red=(Quantum) (QuantumRange-ScaleCharToQuantum(ReadBlobByte(image)));
       q++;
     }
     if ((image->columns % 2) != 0)
@@ -237,7 +238,7 @@ static Image *ReadSCTImage(const ImageInfo *image_info,ExceptionInfo *exception)
       break;
     for (x=0; x < (long) image->columns; x++)
     {
-      q->green=(Quantum) (MaxRGB-ScaleCharToQuantum(ReadBlobByte(image)));
+      q->green=(Quantum) (QuantumRange-ScaleCharToQuantum(ReadBlobByte(image)));
       q++;
     }
     if ((image->columns % 2) != 0)
@@ -248,7 +249,7 @@ static Image *ReadSCTImage(const ImageInfo *image_info,ExceptionInfo *exception)
     indexes=GetIndexes(image);
     for (x=0; x < (long) image->columns; x++)
     {
-      q->blue=(Quantum) (MaxRGB-ScaleCharToQuantum(ReadBlobByte(image)));
+      q->blue=(Quantum) (QuantumRange-ScaleCharToQuantum(ReadBlobByte(image)));
       q++;
     }
     if ((image->columns % 2) != 0)
@@ -260,7 +261,7 @@ static Image *ReadSCTImage(const ImageInfo *image_info,ExceptionInfo *exception)
           break;
         for (x=0; x < (long) image->columns; x++)
         {
-          indexes[x]=(IndexPacket) (MaxRGB-
+          indexes[x]=(IndexPacket) (QuantumRange-
             ScaleCharToQuantum(ReadBlobByte(image)));
           q++;
         }
