@@ -437,7 +437,7 @@ static Image *ReadTXTImage(const ImageInfo *image_info,ExceptionInfo *exception)
       if (scale == (Quantum *) NULL)
         ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
       for (i=0; i <= (long) max_value; i++)
-        scale[i]=ScaleXToQuantum(i,max_value);
+        scale[i]=ScaleAnyToQuantum(i,max_value);
     }
   pixel.opacity=OpaqueOpacity;
   while (ReadBlobString(image,text) != (char *) NULL)
