@@ -98,7 +98,7 @@ MagickExport const PixelPacket *AcquireCacheView(const ViewInfo *view_info,
   assert(view_info->signature == MagickSignature);
   assert(view_info->image != (Image *) NULL);
   if (view_info->image->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
       view_info->image->filename);
   pixels=AcquireCacheNexus(view_info->image,x,y,columns,rows,view_info->id,
     exception);
@@ -134,7 +134,7 @@ MagickExport void CloseCacheView(ViewInfo *view_info)
   assert(view_info->signature == MagickSignature);
   assert(view_info->image != (Image *) NULL);
   if (view_info->image->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
       view_info->image->filename);
   if (view_info->id != 0)
     DestroyCacheNexus(view_info->image->cache,view_info->id);
@@ -182,7 +182,7 @@ MagickExport PixelPacket *GetCacheView(ViewInfo *view_info,const long x,const lo
   assert(view_info->signature == MagickSignature);
   assert(view_info->image != (Image *) NULL);
   if (view_info->image->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
       view_info->image->filename);
   return(GetCacheNexus(view_info->image,x,y,columns,rows,view_info->id));
 }
@@ -217,7 +217,7 @@ MagickExport IndexPacket *GetCacheViewIndexes(const ViewInfo *view_info)
   assert(view_info->signature == MagickSignature);
   assert(view_info->image != (Image *) NULL);
   if (view_info->image->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
       view_info->image->filename);
   return(GetNexusIndexes(view_info->image->cache,view_info->id));
 }
@@ -251,7 +251,7 @@ MagickExport PixelPacket *GetCacheViewPixels(const ViewInfo *view_info)
   assert(view_info->signature == MagickSignature);
   assert(view_info->image != (Image *) NULL);
   if (view_info->image->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
       view_info->image->filename);
   return(GetNexusPixels(view_info->image->cache,view_info->id));
 }
@@ -287,7 +287,7 @@ MagickExport ViewInfo *OpenCacheView(Image *image)
   assert(image != (Image *) NULL);
   assert(image->signature == MagickSignature);
   if (image->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),image->filename);
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   view_info=(ViewInfo *) AcquireMagickMemory(sizeof(ViewInfo));
   if (view_info == (ViewInfo *) NULL)
     ThrowMagickFatalException(ResourceLimitFatalError,"MemoryAllocationFailed",
@@ -335,7 +335,7 @@ MagickExport PixelPacket *SetCacheView(ViewInfo *view_info,const long x,
   assert(view_info->signature == MagickSignature);
   assert(view_info->image != (Image *) NULL);
   if (view_info->image->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
       view_info->image->filename);
   return(SetCacheNexus(view_info->image,x,y,columns,rows,view_info->id));
 }
@@ -371,7 +371,7 @@ MagickExport MagickBooleanType SyncCacheView(ViewInfo *view_info)
   assert(view_info->signature == MagickSignature);
   assert(view_info->image != (Image *) NULL);
   if (view_info->image->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
       view_info->image->filename);
   return(SyncCacheNexus(view_info->image,view_info->id));
 }
