@@ -84,7 +84,8 @@ MagickExport void AppendImageToList(Image **images,const Image *image)
     return;
   assert(image->signature == MagickSignature);
   if (image->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),image->filename);
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
+  RelinquishImageResources(image);
   if ((*images) == (Image *) NULL)
     {
       *images=(Image *) image;
@@ -192,7 +193,8 @@ MagickExport void DeleteImageFromList(Image **images)
     return;
   assert((*images)->signature == MagickSignature);
   if ((*images)->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),(*images)->filename);
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
+      (*images)->filename);
   p=(*images);
   if ((p->previous == (Image *) NULL) && (p->next == (Image *) NULL))
     *images=(Image *) NULL;
@@ -244,7 +246,7 @@ MagickExport Image *DestroyImageList(Image *images)
     return((Image *) NULL);
   assert(images->signature == MagickSignature);
   if (images->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),images->filename);
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",images->filename);
   for (p=images; p->previous != (Image *) NULL; p=p->previous);
   for (images=p; p != (Image *) NULL; images=p)
   {
@@ -328,7 +330,7 @@ MagickExport Image *GetImageFromList(const Image *images,const long index)
     return((Image *) NULL);
   assert(images->signature == MagickSignature);
   if (images->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),images->filename);
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",images->filename);
   for (p=images; p->previous != (Image *) NULL; p=p->previous);
   for (i=0; p != (Image *) NULL; p=p->next)
     if (i++ == ((index < 0) ? (long) GetImageListLength(images)+index : index))
@@ -407,7 +409,7 @@ MagickExport unsigned long GetImageListLength(const Image *images)
     return(0);
   assert(images->signature == MagickSignature);
   if (images->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),images->filename);
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",images->filename);
   while (images->previous != (Image *) NULL)
     images=images->previous;
   for (i=0; images != (Image *) NULL; images=images->next)
@@ -478,7 +480,8 @@ MagickExport Image *GetNextImageInList(const Image *images)
     return((Image *) NULL);
   assert(images->signature == MagickSignature);
   if (images->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),images->filename);
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",images->filename);
+  RelinquishImageResources(images);
   return(images->next);
 }
 
@@ -510,6 +513,7 @@ MagickExport Image *GetPreviousImageInList(const Image *images)
   if (images == (Image *) NULL)
     return((Image *) NULL);
   assert(images->signature == MagickSignature);
+  RelinquishImageResources(images);
   return(images->previous);
 }
 
@@ -555,7 +559,7 @@ MagickExport Image **ImageListToArray(const Image *images,
     return((Image **) NULL);
   assert(images->signature == MagickSignature);
   if (images->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),images->filename);
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",images->filename);
   group=(Image **) AcquireMagickMemory((size_t)
     (GetImageListLength(images)+1)*sizeof(*group));
   if (group == (Image **) NULL)
@@ -606,7 +610,7 @@ MagickExport void InsertImageInList(Image **images,Image *image)
   assert(image != (Image *) NULL);
   assert(image->signature == MagickSignature);
   if (image->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),image->filename);
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   if ((*images) == (Image *) NULL)
     return;
   assert((*images)->signature == MagickSignature);
@@ -703,7 +707,8 @@ MagickExport Image *RemoveImageFromList(Image **images)
     return((Image *) NULL);
   assert((*images)->signature == MagickSignature);
   if ((*images)->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),(*images)->filename);
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
+      (*images)->filename);
   p=(*images);
   if ((p->previous == (Image *) NULL) && (p->next == (Image *) NULL))
     *images=(Image *) NULL;
@@ -756,7 +761,8 @@ MagickExport Image *RemoveFirstImageFromList(Image **images)
     return((Image *) NULL);
   assert((*images)->signature == MagickSignature);
   if ((*images)->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),(*images)->filename);
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
+      (*images)->filename);
   image=(*images);
   while (image->previous != (Image *) NULL)
     image=image->previous;
@@ -803,7 +809,8 @@ MagickExport Image *RemoveLastImageFromList(Image **images)
     return((Image *) NULL);
   assert((*images)->signature == MagickSignature);
   if ((*images)->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),(*images)->filename);
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
+      (*images)->filename);
   image=(*images);
   while (image->next != (Image *) NULL)
     image=image->next;
@@ -848,7 +855,7 @@ MagickExport void ReplaceImageInList(Image **images,Image *image)
   assert(image != (Image *) NULL);
   assert(image->signature == MagickSignature);
   if (image->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),image->filename);
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   if ((*images) == (Image *) NULL)
     return;
   assert((*images)->signature == MagickSignature);
@@ -898,7 +905,8 @@ MagickExport void ReverseImageList(Image **images)
     return;
   assert((*images)->signature == MagickSignature);
   if ((*images)->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),(*images)->filename);
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
+      (*images)->filename);
   for (p=(*images); p->next != (Image *) NULL; p=p->next);
   *images=p;
   for ( ; p != (Image *) NULL; p=p->next)
@@ -954,7 +962,8 @@ MagickExport void SpliceImageIntoList(Image **images,const unsigned long length,
     return;
   assert((*images)->signature == MagickSignature);
   if ((*images)->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),(*images)->filename);
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
+      (*images)->filename);
   split=SplitImageList(*images);
   if (split == (Image *) NULL)
     return;
