@@ -893,6 +893,9 @@ static MagickBooleanType LoadMagicList(const char *xml,const char *filename,
 static MagickBooleanType LoadMagicLists(const char *filename,
   ExceptionInfo *exception)
 {
+#if defined(UseEmbeddableMagick)
+  return(LoadMagicList(MagicMap,"built-in",0,exception));
+#else
   char
     path[MaxTextExtent];
 
@@ -925,4 +928,5 @@ static MagickBooleanType LoadMagicLists(const char *filename,
       status|=LoadMagicList(MagicMap,"built-in",0,exception);
     }
   return(status != 0 ? MagickTrue : MagickFalse);
+#endif
 }
