@@ -58,9 +58,6 @@ typedef struct _ModuleInfo
 extern MagickExport char
   **GetModuleList(const char *,unsigned long *,ExceptionInfo *);
 
-extern MagickExport char
-  *TagToModule(const char *);
-
 extern MagickExport const ModuleInfo
   *GetModuleInfo(const char *,ExceptionInfo *),
   **GetModuleInfoList(const char *,unsigned long *,ExceptionInfo *);
@@ -74,7 +71,6 @@ extern MagickExport MagickBooleanType
 
 extern MagickExport void
   DestroyModuleList(void),
-  *GetModuleBlob(const char *,char *,size_t *,ExceptionInfo *),
   RegisterStaticModules(void),
   UnregisterStaticModules(void);
 
