@@ -5,7 +5,7 @@
   You may not use this file except in compliance with the License.
   obtain a copy of the License at
   
-    http://www.imagemagick.org/www/Copyright.html
+    http://www.imagemagick.org/script/license.php
   
   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
@@ -29,13 +29,13 @@ MagickExport char
 
 extern MagickExport MagickBooleanType
   CloneImageProfiles(Image *,const Image *),
-  ProfileImage(Image *,const char *,const unsigned char *,const unsigned long,
+  ProfileImage(Image *,const char *,const void *,const unsigned long,
     const MagickBooleanType),
+  RemoveImageProfile(Image *,const char *),
   SetImageProfile(Image *,const char *,const StringInfo *);
 
 MagickExport StringInfo
-  *GetImageProfile(const Image *,const char *),
-  *RemoveImageProfile(Image *,const char *);
+  *GetImageProfile(const Image *,const char *);
 
 extern MagickExport void
   DestroyImageProfiles(Image *),
