@@ -920,7 +920,7 @@ MagickExport StringInfo *FileToStringInfo(const char *filename)
 %
 %  The format of the FormatMagickString method is:
 %
-%      int FormatMagickString(char *string,const size_t length,
+%      long FormatMagickString(char *string,const size_t length,
 %        const char *format,...)
 %
 %  A description of each parameter follows.
@@ -935,16 +935,13 @@ MagickExport StringInfo *FileToStringInfo(const char *filename)
 %
 %
 */
-MagickExport int FormatMagickString(char *string,const size_t length,
-  const char *format,...)
+
+MagickExport long FormatMagickStringList(char *string,const size_t length,
+  const char *format,va_list operands)
 {
   int
     n;
 
-  va_list
-    operands;
-
-  va_start(operands,format);
 #if defined(HAVE_VSNPRINTF)
   n=vsnprintf(string,length,format,operands);
 #else
@@ -952,6 +949,20 @@ MagickExport int FormatMagickString(char *string,const size_t length,
 #endif
   if (n < 0)
     string[length-1]='\0';
+  return((long) n);
+}
+
+MagickExport long FormatMagickString(char *string,const size_t length,
+  const char *format,...)
+{
+  long
+    n;
+
+  va_list
+    operands;
+
+  va_start(operands,format);
+  n=(long) FormatMagickStringList(string,length,format,operands);
   va_end(operands);
   return(n);
 }
@@ -976,7 +987,7 @@ MagickExport int FormatMagickString(char *string,const size_t length,
 %
 %  The format of the LocaleCompare method is:
 %
-%      int LocaleCompare(const char *p,const char *q)
+%      long LocaleCompare(const char *p,const char *q)
 %
 %  A description of each parameter follows:
 %
@@ -986,14 +997,14 @@ MagickExport int FormatMagickString(char *string,const size_t length,
 %
 %
 */
-MagickExport int LocaleCompare(const char *p,const char *q)
+MagickExport long LocaleCompare(const char *p,const char *q)
 {
   if (p == (char *) NULL)
     return(-1);
   if (q == (char *) NULL)
     return(1);
 #if defined(HAVE_STRCASECMP)
-  return(strcasecmp(p,q));
+  return((long) strcasecmp(p,q));
 #else
   {
     register unsigned char
@@ -1009,7 +1020,7 @@ MagickExport int LocaleCompare(const char *p,const char *q)
       p++;
       q++;
     }
-    return(AsciiMap[c]-AsciiMap[d]);
+    return((long) AsciiMap[c]-AsciiMap[d]);
   }
 #endif
 }
@@ -1072,7 +1083,7 @@ MagickExport void LocaleLower(char *string)
 %
 %  The format of the LocaleNCompare method is:
 %
-%      int LocaleNCompare(const char *p,const char *q,const size_t n)
+%      long LocaleNCompare(const char *p,const char *q,const size_t n)
 %
 %  A description of each parameter follows:
 %
@@ -1084,14 +1095,15 @@ MagickExport void LocaleLower(char *string)
 %
 %
 */
-MagickExport int LocaleNCompare(const char *p,const char *q,const size_t length)
+MagickExport long LocaleNCompare(const char *p,const char *q,
+  const size_t length)
 {
   if (p == (char *) NULL)
     return(-1);
   if (q == (char *) NULL)
     return(1);
 #if defined(HAVE_STRNCASECMP)
-  return(strncasecmp(p,q,length));
+  return((long) strncasecmp(p,q,length));
 #else
   {
     register size_t
@@ -1108,11 +1120,11 @@ MagickExport int LocaleNCompare(const char *p,const char *q,const size_t length)
       if (AsciiMap[c] != AsciiMap[d])
         return(AsciiMap[c]-AsciiMap[d]);
       if (c == '\0')
-        return(0);
+        return(0L);
       p++;
       q++;
     }
-    return(0);
+    return(0L);
   }
 #endif
 }
@@ -1708,7 +1720,7 @@ MagickExport char **StringToList(const char *text)
         if (*p == '\n')
           lines++;
       textlist=(char **)
-        AcquireMagickMemory((size_t) (lines+MaxTextExtent)*sizeof(*textlist));
+        AcquireMagickMemory((size_t) (lines+1)*sizeof(*textlist));
       if (textlist == (char **) NULL)
         ThrowMagickFatalException(ResourceLimitFatalError,"UnableToConvertText",
           text);
@@ -1742,7 +1754,7 @@ MagickExport char **StringToList(const char *text)
       */
       lines=(unsigned long) (strlen(text)/0x14)+1;
       textlist=(char **)
-        AcquireMagickMemory((size_t) (lines+MaxTextExtent)*sizeof(*textlist));
+        AcquireMagickMemory((size_t) (lines+1)*sizeof(*textlist));
       if (textlist == (char **) NULL)
         ThrowMagickFatalException(ResourceLimitFatalError,"UnableToConvertText",
           text);
