@@ -55,17 +55,14 @@
 /*
   Include declarations.
 */
-#include "magick/studio.h"
-#include "magick/client.h"
-#include "magick/display.h"
-#include "magick/exception.h"
-#include "magick/image.h"
-#include "magick/log.h"
-#include "magick/magick.h"
-#include "magick/memory_.h"
-#include "magick/string_.h"
-#include "magick/utility.h"
-#include "magick/version.h"
+#include <stdio.h>
+#include <stdlib.h>
+#include <string.h>
+#include <time.h>
+#include "magick/ImageMagick.h"
+#if defined(__WINDOWS__)
+#include <windows.h>
+#endif
 
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -127,7 +124,7 @@ int main(int argc,char **argv)
         (void) fprintf(stdout,"Version: %s\n",
           GetMagickVersion((unsigned long *) NULL));
         (void) fprintf(stdout,"Copyright: %s\n\n",GetMagickCopyright());
-        Exit(0);
+        exit(0);
       }
   }
   image_info=CloneImageInfo((ImageInfo *) NULL);
@@ -137,6 +134,6 @@ int main(int argc,char **argv)
   image_info=DestroyImageInfo(image_info);
   DestroyExceptionInfo(&exception);
   DestroyMagick();
-  Exit(!status);
+  exit(!status);
   return(MagickFalse);
 }
