@@ -15,8 +15,8 @@
 
   ImageMagick pixel wand API.
 */
-#ifndef _MAGICK_MAGICK_WAND_PRIVATE_H
-#define _MAGICK_MAGICK_WAND_PRIVATE_H
+#ifndef _WAND_MAGICK_WAND_PRIVATE_H
+#define _WAND_MAGICK_WAND_PRIVATE_H
 
 #if defined(__cplusplus) || defined(c_plusplus)
 extern "C" {
